==> aplus_chat-0.2.5.tar.gz: lib/view/profile_view.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:aplus_chat/core/services/stream_socket.dart';
import 'package:aplus_chat/core/services/web_services.dart';
import 'package:aplus_chat/global.dart';
import 'package:aplus_chat/helper/custom_styles.dart';
import 'package:aplus_chat/helper/storages.dart';
import 'package:aplus_chat/model/profile_detail_model.dart';
import 'package:aplus_chat/view/chats_list_view.dart';
import 'package:aplus_chat/view/widgets/comman.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ProfileView extends StatefulWidget {
  const ProfileView({Key? key}) : super(key: key);

  @override
  State<ProfileView> createState() => _ProfileViewState();
}

class _ProfileViewState extends State<ProfileView> {
  TextEditingController txtUserName = TextEditingController();
  var loadData = false.obs;
  @override
  void initState() {
    super.initState();
    //loadData.value = true;
    // getUserProfileApi();

    txtUserName.text = AppStorages.myUserName.value;

  }

  // ignore: prefer_typing_uninitialized_variables

  var profileImage = File("").obs;
  var selectedProfileURl = "";
  var saveLoader = false.obs;
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      bottomNavigationBar: Obx(
        () => SafeArea(
          child: GestureDetector(
            onTap: saveLoader.value
                ? null
                : () {
                    if (txtUserName.text.isNotEmpty) {
                      saveLoader.value = true;
                      updateProfileApi();
                    } else {}
                  },
            child: Container(
              height: 50,
              margin: const EdgeInsets.only(
                  top: 16, left: 20, right: 20, bottom: 12),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(8.0),
                color: Colors.blue,
              ),
              child: Center(
                child: saveLoader.value
                    ? const CircularProgressIndicator(color: Colors.white)
                    : Text(
                        "Save",
                        style: CustomTextStyles.semiBold(
                            fontSize: 18.0, fontColor: Colors.white),
                      ),
              ),
            ),
          ),
        ),
      ),
      body: SafeArea(
        child: Column(
          // mainAxisAlignment: MainAxisAlignment.center,
          children: [
            appBar(),
            Obx(
              () => Expanded(
                child: loadData.value
                    ? const Center(child: CircularProgressIndicator())
                    : Container(
                            padding: const EdgeInsets.only(left: 20, right: 20),
                            width: MediaQuery.of(context).size.width,
                            color: Colors.white,
                            child: Column(
                              children: [
                                const SizedBox(
                                  height: 24,
                                ),
                                Obx(
                                  () => Stack(
                                    alignment: AlignmentDirectional.center,
                                    children: [
                                      GestureDetector(
                                        onTap: () async {
                                          File pickedFile;
                                          FilePickerResult? result =
                                              await FilePicker.platform
                                                  .pickFiles(
                                            type: FileType.media,
                                            withData: true,
                                          );
                                          pickedFile =
                                              File(result!.paths[0].toString());
                                          profileImage.value = pickedFile;
                                          uploadImageLoader.value = true;
                                          uploadImageApi(
                                            file: pickedFile.path,

                                          );
                                        },
                                        child: Obx(
                                          () => selectedProfileURl == ""
                                              ? Common.profileNetworkImage(
                                                  borderRadius: 200.0,
                                                  height: 200.0,
                                                  width: 200.0,
                                                  imageUrl: AppStorages.myProfilePicture.value,
                                                )
                                              : ClipRRect(
                                                  borderRadius:
                                                      BorderRadius.circular(
                                                          200),
                                                  child: Container(
                                                    color: Colors.black12,
                                                    child: Image.file(
                                                      File(
                                                        profileImage.value.path,
                                                      ),
                                                      height: 200.0,
                                                      width: 200.0,
                                                      fit: BoxFit.cover,
                                                    ),
                                                  ),
                                                ),
                                        ),
                                      ),
                                      uploadImageLoader.value
                                          ? const CircularProgressIndicator()
                                          : const Icon(
                                              Icons.camera_alt_outlined,
                                              color: Colors.white,
                                              size: 30.0,
                                            )
                                    ],
                                  ),
                                ),
                                const SizedBox(
                                  height: 32,
                                ),
                                TextField(
                                  controller: txtUserName,
                                  decoration: InputDecoration(
                                    hintText: "Enter User Name",
                                    hintStyle: CustomTextStyles.medium(
                                        fontSize: 14.0,
                                        fontColor: Colors.black38),
                                    filled: true,
                                    fillColor: const Color(0xffEEEEEF),
                                    border: searchCommonBorderStyle,
                                    enabledBorder: searchCommonBorderStyle,
                                    disabledBorder: searchCommonBorderStyle,
                                    focusedBorder: searchCommonBorderStyle,
                                    focusedErrorBorder: searchCommonBorderStyle,
                                    errorBorder: searchCommonBorderStyle,
                                    contentPadding: const EdgeInsets.only(
                                        left: 6, right: 6),
                                  ),
                                ),
                                const SizedBox(
                                  height: 8,
                                ),
                                Text(
                                  "This is not your username or pin. This name will be visible to your chat contact.",
                                  style: CustomTextStyles.normal(
                                      fontSize: 14.0,
                                      fontColor: Colors.black54),
                                ),
                                const SizedBox(height: 16),
                              ],
                            ),
                          ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  var searchCommonBorderStyle = const OutlineInputBorder(
    borderSide: BorderSide(
      color: Color(0xffE6E6E6),
    ),
  );

  Widget appBar() {
    return Container(
      color: const Color(0xffE5E5EA),
      child: Row(
        children: [
          IconButton(
              onPressed: () {
                Navigator.pop(context);
              },
              icon:
                Icon(Platform.isAndroid?Icons.arrow_back:Icons.arrow_back_ios,
                size: 25.0,
              )),
          const SizedBox(
            width: 8,
          ),
          Text(
            "Profile",
            style: CustomTextStyles.medium(
                fontSize: 18.0, fontColor: Colors.black),
          ),
        ],
      ),
    );
  }

  updateProfileApi() {
   
    
    var body = {
      "secretKey": AppStorages.secKey,
      "name": txtUserName.text,
      "profilePicture": selectedProfileURl == ""
          ? AppStorages.myProfilePicture.value
          : selectedProfileURl,
      "userId": AppStorages.myUserId,
    };

    socket.emit("update-profile",body);

    socket.on("update-profile-res", (data) {

      if(data["isSuccess"]){
        // AppStorages.setChatUserData(
        //     selectedProfileURl == ""
        //         ? AppStorages.myProfilePicture.value
        //         : selectedProfileURl,
        //     setKey: SessionKeys.chatUserProfilePic);
        AppStorages.myProfilePicture.value = selectedProfileURl == ""
            ? AppStorages.myProfilePicture.value
            : selectedProfileURl;
        AppStorages.myUserName.value =
            txtUserName.text;
        saveLoader.value = false;
        Navigator.pushReplacement(
            context,
            MaterialPageRoute(
                builder: (BuildContext context) => const ChatsListView()));
        socket.off("update-profile-res");
      }
    });

    // Webservice.postRequest(
    //     context: Get.context,
    //     uri: Global.updateProfile + AppStorages.myUserId,
    //     body: body,
    //     baseUrl: Global.baseApiUrl,
    //     hasBearer: false,
    //     onSuccess: (response) {
    //       if (response != null) {
    //         AppStorages.setChatUserData(txtUserName.text,
    //             setKey: SessionKeys.chatUserName);
    //         AppStorages.setChatUserData(
    //             selectedProfileURl == ""
    //                 ? AppStorages.myProfilePicture.value
    //                 : selectedProfileURl,
    //             setKey: SessionKeys.chatUserProfilePic);
    //         AppStorages.myProfilePicture.value = selectedProfileURl == ""
    //             ? AppStorages.myProfilePicture.value
    //             : selectedProfileURl;
    //         AppStorages.myUserName.value =
    //             AppStorages.getChatUserData(getKey: SessionKeys.chatUserName);
    //         AppStorages.myFirstName.value = AppStorages.getChatUserData(
    //             getKey: SessionKeys.chatUserFirstName);
    //         AppStorages.myLastName.value = AppStorages.getChatUserData(
    //             getKey: SessionKeys.chatUserLastName);
    //         AppStorages.myProfilePicture = AppStorages.getChatUserData(
    //             getKey: SessionKeys.chatUserProfilePic);
    //         AppStorages.myUserName.value =
    //             AppStorages.getChatUserData(getKey: SessionKeys.chatUserName);
    //         AppStorages.myFirstName.value = AppStorages.getChatUserData(
    //             getKey: SessionKeys.chatUserFirstName);
    //         AppStorages.myLastName.value = AppStorages.getChatUserData(
    //             getKey: SessionKeys.chatUserLastName);
    //         AppStorages.myEmail.value =
    //             AppStorages.getChatUserData(getKey: SessionKeys.chatUserEmail);
    //         AppStorages.myMobile.value =
    //             AppStorages.getChatUserData(getKey: SessionKeys.chatUserMobile);
    //         AppStorages.myProfilePicture.value = AppStorages.getChatUserData(
    //             getKey: SessionKeys.chatUserProfilePic);
    //         AppStorages.chatFCMToken.value =
    //             AppStorages.getChatUserData(getKey: SessionKeys.chatFcmToken);
    //         saveLoader.value = false;
    //         Navigator.pushReplacement(
    //             context,
    //             MaterialPageRoute(
    //                 builder: (BuildContext context) => const ChatsListView()));
    //       }
    //     },
    //     onFailure: (response) {
    //       saveLoader.value = false;
    //     },
    //     onConnectionFailed: (response) {
    //       saveLoader.value = false;
    //     });
  }

  var uploadImageLoader = false.obs;
  uploadImageApi({contentType, file, fileName, pickdFile, fileType}) async {
    var body = {
      "secretKey": AppStorages.secKey.toString(),
      "userId":AppStorages.myUserId.toString(),
      "groupId":"",
      "type":"image",
      "isChat":"0",
    };
    Webservice.uploadImage(
      uri: Global.uploadFileNew,
      body: body,
      hasBearer: true,
      onSuccess: (response) {
        var res = jsonDecode(response);
        selectedProfileURl = res['file'];
        uploadImageLoader.value = false;
      },
      onFailure: (v) {
        uploadImageLoader.value = false;
      }, file: File(file), fileType: 'selectFile',
    );
  }

  ProfileDetailModel? profileData;

  getUserProfileApi() async {
    var body = {
      "secretKey": AppStorages.secKey,
      "userId": AppStorages.myUserId
    };
    Webservice.postRequest(
      uri: Global.getUserDetails,
      body: body,
      baseUrl: Global.baseApiUrl,
      hasBearer: false,
      onSuccess: (response) {
        loadData.value = false;
        var res = jsonDecode(response);
        profileData = ProfileDetailModel(
            userName: res['item']['username'],
            userId: res['item']['userId'],
            firstName: res['item']['firstName'],
            lastName: res['item']['lastName'],
            name: res['item']['name'],
            email: res['item']['email'],
            secretKey: res['item']['secretKey'],
            profilePicture: res['item']['profilePicture']);
        txtUserName.text = profileData!.userName!;
      },
      onFailure: (v) {
        loadData.value = false;
      },
    );
  }
}

==> aplus_chat-0.2.7.tar.gz: lib/view/profile_view.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:aplus_chat/core/services/stream_socket.dart';
import 'package:aplus_chat/core/services/web_services.dart';
import 'package:aplus_chat/global.dart';
import 'package:aplus_chat/helper/custom_styles.dart';
import 'package:aplus_chat/helper/storages.dart';
import 'package:aplus_chat/model/profile_detail_model.dart';
import 'package:aplus_chat/view/chats_list_view.dart';
import 'package:aplus_chat/view/widgets/comman.dart';
import 'package:aplus_chat/view/widgets/themes/cometchat_theme.dart';
import 'package:aplus_chat/view/widgets/themes/palette.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ProfileView extends StatefulWidget {
   ProfileView({Key? key,this.theme}) : super(key: key);
  CometChatTheme? theme;

  @override
  State<ProfileView> createState() => _ProfileViewState();
}

class _ProfileViewState extends State<ProfileView> {
  TextEditingController txtUserName = TextEditingController();
  var loadData = false.obs;
  @override
  void initState() {
    super.initState();
    txtUserName.text = AppStorages.myUserName.value;

  }

  // ignore: prefer_typing_uninitialized_variables

  var profileImage = File("").obs;
  var selectedProfileURl = "";
  var saveLoader = false.obs;
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: widget.theme!.palette.mode == PaletteThemeModes.light?Colors.white:Colors.black54,
      bottomNavigationBar: Obx(
        () => SafeArea(
          child: GestureDetector(
            onTap: saveLoader.value
                ? null
                : () {
                    if (txtUserName.text.isNotEmpty) {
                      saveLoader.value = true;
                      updateProfileApi();
                    } else {}
                  },
            child: Container(
              height: 50,
              margin: const EdgeInsets.only(
                  top: 16, left: 20, right: 20, bottom: 12),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(8.0),
                color: widget.theme!.palette.getAccent(),
              ),
              child: Center(
                child: saveLoader.value
                    ? const CircularProgressIndicator(color: Colors.white)
                    : Text(
                        "Save",
                        style: CustomTextStyles.semiBold(
                            fontSize: 18.0, fontColor: Colors.white),
                      ),
              ),
            ),
          ),
        ),
      ),
      body: SafeArea(
        child: Column(
          // mainAxisAlignment: MainAxisAlignment.center,
          children: [
            appBar(),
            Obx(
              () => Expanded(
                child: loadData.value
                    ? const Center(child: CircularProgressIndicator())
                    : Container(
                            padding: const EdgeInsets.only(left: 20, right: 20),
                            width: MediaQuery.of(context).size.width,
                            color: widget.theme!.palette.mode == PaletteThemeModes.light?Colors.white:Colors.black54,
                            child: Column(
                              children: [
                                const SizedBox(
                                  height: 24,
                                ),
                                Obx(
                                  () => Stack(
                                    alignment: AlignmentDirectional.center,
                                    children: [
                                      GestureDetector(
                                        onTap: () async {
                                          File pickedFile;
                                          FilePickerResult? result =
                                              await FilePicker.platform
                                                  .pickFiles(
                                            type: FileType.media,
                                            withData: true,
                                          );
                                          pickedFile =
                                              File(result!.paths[0].toString());
                                          profileImage.value = pickedFile;
                                          uploadImageLoader.value = true;
                                          uploadImageApi(
                                            file: pickedFile.path,

                                          );
                                        },
                                        child: Obx(
                                          () => selectedProfileURl == ""
                                              ? Common.profileNetworkImage(
                                                  borderRadius: 200.0,
                                                  height: 200.0,
                                                  width: 200.0,
                                                  imageUrl: AppStorages.myProfilePicture.value,
                                                )
                                              : ClipRRect(
                                                  borderRadius:
                                                      BorderRadius.circular(
                                                          200),
                                                  child: Container(
                                                    color: Colors.black12,
                                                    child: Image.file(
                                                      File(
                                                        profileImage.value.path,
                                                      ),
                                                      height: 200.0,
                                                      width: 200.0,
                                                      fit: BoxFit.cover,
                                                    ),
                                                  ),
                                                ),
                                        ),
                                      ),
                                      uploadImageLoader.value
                                          ? const CircularProgressIndicator()
                                          :  Icon(
                                              Icons.camera_alt_outlined,
                                              color: widget.theme!.palette.getAccent(),
                                              size: 30.0,
                                            )
                                    ],
                                  ),
                                ),
                                const SizedBox(
                                  height: 32,
                                ),
                                TextField(
                                  controller: txtUserName,
                                  decoration: InputDecoration(
                                    hintText: "Enter User Name",
                                    hintStyle: CustomTextStyles.medium(
                                        fontSize: 14.0,
                                        fontColor: Colors.black38),
                                    filled: true,
                                    fillColor:widget.theme!.palette.getAccent200(),
                                    border: searchCommonBorderStyle,
                                    enabledBorder: searchCommonBorderStyle,
                                    disabledBorder: searchCommonBorderStyle,
                                    focusedBorder: searchCommonBorderStyle,
                                    focusedErrorBorder: searchCommonBorderStyle,
                                    errorBorder: searchCommonBorderStyle,
                                    contentPadding: const EdgeInsets.only(
                                        left: 6, right: 6),
                                  ),
                                ),
                                const SizedBox(
                                  height: 8,
                                ),
                                Text(
                                  "This is not your username or pin. This name will be visible to your chat contact.",
                                  style: CustomTextStyles.normal(
                                      fontSize: 14.0,
                                      fontColor: widget.theme!.palette.getAccent800()),
                                ),
                                const SizedBox(height: 16),
                              ],
                            ),
                          ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  var searchCommonBorderStyle = const OutlineInputBorder(
    borderSide: BorderSide(
      color: Color(0xffE6E6E6),
    ),
  );

  Widget appBar() {
    return Container(
      color: widget.theme!.palette.getAccent200(),
      child: Row(
        children: [
          IconButton(
              onPressed: () {
                Navigator.pop(context);
              },
              icon:
                Icon(Platform.isAndroid?Icons.arrow_back:Icons.arrow_back_ios,color:  widget.theme!.palette.getAccent800(),
                size: 25.0,
              )),
          const SizedBox(
            width: 8,
          ),
          Text(
            "Profile",
            style: CustomTextStyles.medium(
                fontSize: 18.0, fontColor: widget.theme!.palette.getAccent800()),
          ),
        ],
      ),
    );
  }

  updateProfileApi() {
   
    
    var body = {
      "secretKey": AppStorages.secKey,
      "name": txtUserName.text,
      "profilePicture": selectedProfileURl == ""
          ? AppStorages.myProfilePicture.value
          : selectedProfileURl,
      "userId": AppStorages.myUserId,
    };

    socket.emit("update-profile",body);

    socket.on("update-profile-res", (data) {

      if(data["isSuccess"]){
        // AppStorages.setChatUserData(
        //     selectedProfileURl == ""
        //         ? AppStorages.myProfilePicture.value
        //         : selectedProfileURl,
        //     setKey: SessionKeys.chatUserProfilePic);
        AppStorages.myProfilePicture.value = selectedProfileURl == ""
            ? AppStorages.myProfilePicture.value
            : selectedProfileURl;
        AppStorages.myUserName.value =
            txtUserName.text;
        saveLoader.value = false;
        Navigator.pushReplacement(
            context,
            MaterialPageRoute(
                builder: (BuildContext context) =>  ChatsListView()));
        socket.off("update-profile-res");
      }
    });

  }

  var uploadImageLoader = false.obs;
  uploadImageApi({contentType, file, fileName, pickdFile, fileType}) async {
    var body = {
      "secretKey": AppStorages.secKey.toString(),
      "userId":AppStorages.myUserId.toString(),
      "groupId":"",
      "type":"image",
      "isChat":"0",
    };
    Webservice.uploadImage(
      uri: Global.uploadFileNew,
      body: body,
      hasBearer: true,
      onSuccess: (response) {
        var res = jsonDecode(response);
        selectedProfileURl = res['file'];
        uploadImageLoader.value = false;
      },
      onFailure: (v) {
        uploadImageLoader.value = false;
      }, file: File(file), fileType: 'selectFile',
    );
  }

  ProfileDetailModel? profileData;

  getUserProfileApi() async {
    var body = {
      "secretKey": AppStorages.secKey,
      "userId": AppStorages.myUserId
    };
    Webservice.postRequest(
      uri: Global.getUserDetails,
      body: body,
      baseUrl: Global.baseApiUrl,
      hasBearer: false,
      onSuccess: (response) {
        loadData.value = false;
        var res = jsonDecode(response);
        profileData = ProfileDetailModel(
            userName: res['item']['username'],
            userId: res['item']['userId'],
            firstName: res['item']['firstName'],
            lastName: res['item']['lastName'],
            name: res['item']['name'],
            email: res['item']['email'],
            secretKey: res['item']['secretKey'],
            profilePicture: res['item']['profilePicture']);
        txtUserName.text = profileData!.userName!;
      },
      onFailure: (v) {
        loadData.value = false;
      },
    );
  }
}
